@@ -217,15 +217,20 @@ static FILE *Oops_objdump(const char *file, const OPTIONS *options)
 {
     char *cmd;
     FILE *f;
-    static char const objdump_options[] = "-dhf ";
+    int cmd_strlen;
+    static char const objdump_options[] = "-dhf --target=";
     static char const procname[] = "Oops_objdump";
 
-    cmd = malloc(strlen(path_objdump)+1+strlen(objdump_options)+strlen(file)+1);
+    /* remember to leave space for spaces */
+    cmd_strlen = strlen(path_objdump)+1+strlen(objdump_options)+strlen(options->target)+1+strlen(file)+1;
+    cmd = malloc(cmd_strlen);
     if (!cmd)
 	malloc_error(procname);
     strcpy(cmd, path_objdump);
     strcat(cmd, " ");
     strcat(cmd, objdump_options);
+    strcat(cmd, options->target);
+    strcat(cmd, " ");
     strcat(cmd, file);
     DEBUG(2, "command '%s'", cmd);
     f = popen_local(cmd, procname);
@@ -1743,7 +1748,7 @@ static int Oops_print(const char *line, const char **text, char ***string,
 	    "^("			/* start of line */
 	    " +"			/* leading spaces */
 	    "|[^ ]{3} [ 0-9][0-9] [0-9]{2}:[0-9]{2}:[0-9]{2} "
-	      "[^ ]+ kernel: +"		/* syslogd */
+	      "[^ ]+( kernel:)? +"	/* syslogd, syslog-ng */
 	    "|<[0-9]+>"			/* kmsg */
 	    "|[0-9]+\\|[^|]+\\|[^|]+\\|[^|]+\\|"	/* syslog-ng */
 	    "|[0-9][AC] [0-9]{3} [0-9]{3}[cir][0-9]{2}:"	/* SNIA */
